@@ -15,7 +15,7 @@ from .text import _get_abstract, _get_text
 searchtext = Union[str, List[str]]
 searchtexts = Union[searchtext, List[searchtext]]
 textlist = List[Dict[str, Any]]
-
+nestedlist = List[List[str]
 
 class Paperset:
     def __init__(self, directory: str) -> None:
@@ -74,15 +74,19 @@ def _search(ps: Union[Paperset, textlist], txt: Any) -> textlist:
         or any(c in _get_abstract(x).lower() for c in txt)
     ]
 
-
 def search(
     ps: Union[Paperset, textlist],
-    terms: Union[searchtexts, searchtext, List[List[str]]],
+    terms: Union[searchtexts, searchtext, nestedlist]],
 ) -> textlist:
     if type(terms) is not list:
         raise ValueError("search terms must be a list!!")
-    if len(terms) != 1:
-        return reduce(lambda x, y: _search(x, y), terms, ps)
+    types = [type(x) for x in terms]
+    nests = len(list(filter(lambda x: x is list, types)))
+    if nests != 0:
+        out = ps
+        for t in terms:
+            out = _search(out, t)
+            return out
     else:
         return _search(ps, terms)
 
