@@ -37,4 +37,4 @@ txt = [["covid", "novel coronavirus"], ["ventilator", "cpap", "bipap"]]
 
 x = cotools.search(data, txt)
 print(len(x))
-print(len(cotools.search(data, txt[0])))
+print(len(cotools.search(data, txt[-1])))
